.. Copyright (C) 2015-2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The `rsyslog <https://www.rsyslog.com/>`_ package is used to read, process, store
and forward system logs in different ways, on local or remote systems. The
``debops.rsyslog`` role can be used to easily configure log forwarding to
a central log server, as well as store logs on the filesystem or other storage
backends.
